@@ -1,15 +1,11 @@
 #' Lower Partial Moment
 #'
 #' This function generates a univariate lower partial moment for any degree or target.
-#' @param degree \code{degree = 0} is frequency, \code{degree = 1} is area.
-#' @param target Typically set to mean, but does not have to be.
-#' @param variable Variable
+#' @param degree integer; \code{(degree = 0)} is frequency, \code{(degree = 1)} is area.
+#' @param target numeric; Typically set to mean, but does not have to be. (Vectorized)
+#' @param variable a numeric vector.
 #' @return LPM of variable
 #' @keywords partial moments, mean, variance, CDF
-#' @importFrom grDevices adjustcolor rainbow
-#' @importFrom graphics abline boxplot legend lines par plot points segments text matplot title axis mtext
-#' @importFrom stats coef cor lm na.omit sd median complete.cases resid uniroot aggregate density
-#' @importFrom rgl plot3d points3d shade3d cube3d
 #' @author Fred Viole, OVVO Financial Systems
 #' @references Viole, F. and Nawrocki, D. (2013) "Nonlinear Nonparametric Statistics: Using Partial Moments"
 #' \url{http://amzn.com/1490523995}
@@ -19,17 +15,18 @@
 #' LPM(0,mean(x),x)
 #' @export
 
-LPM<- function(degree,target,variable)
- {sum((target - (variable[variable <= target]))^degree)/length(variable)}
+LPM<- function(degree,target,variable){
+sum((target - (variable[variable <= target]))^degree)/length(variable)}
+LPM<- Vectorize(LPM,vectorize.args = 'target')
 
 
 
 #' Upper Partial Moment
 #'
 #' This function generates a univariate upper partial moment for any degree or target.
-#' @param degree \code{degree = 0} is frequency, \code{degree = 1} is area.
-#' @param target Typically set to mean, but does not have to be.
-#' @param variable Variable
+#' @param degree integer; \code{(degree = 0)} is frequency, \code{(degree = 1)} is area.
+#' @param target numeric; Typically set to mean, but does not have to be. (Vectorized)
+#' @param variable a numeric vector.
 #' @return UPM of variable
 #' @keywords partial moments, mean, variance, upper CDF
 #' @author Fred Viole, OVVO Financial Systems
@@ -44,18 +41,18 @@ LPM<- function(degree,target,variable)
 
 UPM<- function(degree,target,variable){
   sum(((variable[variable > target]) - target)^degree)/length(variable)}
-
+UPM<- Vectorize(UPM,vectorize.args = 'target')
 
 #' Co-Upper Partial Moment
 #' (Upper Right Quadrant 1)
 #'
-#' This function generates a multivariate co-upper partial moment for any degree or target.
-#' @param degree.x Degree for variable X.  \code{degree.x = 0} is frequency, \code{degree.x = 1} is area.
-#' @param degree.y Degree for variable Y.  \code{degree.y = 0} is frequency, \code{degree.y = 1} is area.
-#' @param x Variable X
-#' @param y Variable Y
-#' @param target.x Typically the mean of Variable X, but does not have to be.
-#' @param target.y Typically the mean of Variable Y, but does not have to be.
+#' This function generates a co-upper partial moment between two variables for any degree or target.
+#' @param degree.x integer; Degree for variable X.  \code{(degree.x = 0)} is frequency, \code{(degree.x = 1)} is area.
+#' @param degree.y integer; Degree for variable Y.  \code{(degree.y = 0)} is frequency, \code{(degree.y = 1)} is area.
+#' @param x a numeric vector.
+#' @param y a numeric vector.
+#' @param target.x numeric; Typically the mean of Variable X for classical statistics equivalences, but does not have to be. (Vectorized)
+#' @param target.y numeric; Typically the mean of Variable Y for classical statistics equivalences, but does not have to be. (Vectorized)
 #' @return Co-UPM of two variables
 #' @keywords partial moments, covariance
 #' @author Fred Viole, OVVO Financial Systems
@@ -75,17 +72,18 @@ Co.UPM<- function(degree.x,degree.y,x,y,target.x=mean(x),target.y=mean(y)){
   y[y>0]<- y[y>0]^degree.y
   return(sum(x*y)/length(x))
   }
+Co.UPM<- Vectorize(Co.UPM,vectorize.args = c('target.x','target.y'))
 
 #' Co-Lower Partial Moment
 #' (Lower Left Quadrant 4)
 #'
-#' This function generates a multivariate co-lower partial moment for any degree or target.
-#' @param degree.x Degree for variable X.  \code{degree.x = 0} is frequency, \code{degree.x = 1} is area.
-#' @param degree.y Degree for variable Y.  \code{degree.y = 0} is frequency, \code{degree.y = 1} is area.
-#' @param x Variable X
-#' @param y Variable Y
-#' @param target.x Typically the mean of Variable X, but does not have to be.
-#' @param target.y Typically the mean of Variable Y, but does not have to be.
+#' This function generates a co-lower partial moment for between two variables any degree or target.
+#' @param degree.x integer; Degree for variable X.  \code{(degree.x = 0)} is frequency, \code{(degree.x = 1)} is area.
+#' @param degree.y integer; Degree for variable Y.  \code{(degree.y = 0)} is frequency, \code{(degree.y = 1)} is area.
+#' @param x a numeric vector.
+#' @param y a numeric vector.
+#' @param target.x numeric; Typically the mean of Variable X for classical statistics equivalences, but does not have to be. (Vectorized)
+#' @param target.y numeric; Typically the mean of Variable Y for classical statistics equivalences, but does not have to be. (Vectorized)
 #' @return Co-LPM of two variables
 #' @keywords partial moments, covariance
 #' @author Fred Viole, OVVO Financial Systems
@@ -104,17 +102,18 @@ Co.LPM<- function(degree.x,degree.y,x,y,target.x=mean(x),target.y=mean(y)){
   y[y>0]<- y[y>0]^degree.y
   return(sum(x*y)/length(x))
   }
+Co.LPM<- Vectorize(Co.LPM,vectorize.args = c('target.x','target.y'))
 
 #' Divergent-Lower Partial Moment
 #' (Lower Right Quadrant 3)
 #'
-#' This function generates a multivariate divergent lower partial moment for any degree or target.
-#' @param degree.x Degree for variable X.  \code{degree.x = 0} is frequency, \code{degree.x = 1} is area.
-#' @param degree.y Degree for variable Y.  \code{degree.y = 0} is frequency, \code{degree.y = 1} is area.
-#' @param x Variable X
-#' @param y Variable Y
-#' @param target.x Typically the mean of Variable X, but does not have to be.
-#' @param target.y Typically the mean of Variable Y, but does not have to be.
+#' This function generates a divergent lower partial moment between two variables for any degree or target.
+#' @param degree.x integer; Degree for variable X.  \code{(degree.x = 0)} is frequency, \code{(degree.x = 1)} is area.
+#' @param degree.y integer; Degree for variable Y.  \code{(degree.y = 0)} is frequency, \code{(degree.y = 1)} is area.
+#' @param x a numeric vector.
+#' @param y a numeric vector.
+#' @param target.x numeric; Typically the mean of Variable X for classical statistics equivalences, but does not have to be. (Vectorized)
+#' @param target.y numeric; Typically the mean of Variable Y for classical statistics equivalences, but does not have to be. (Vectorized)
 #' @return Divergent LPM of two variables
 #' @keywords partial moments, covariance
 #' @author Fred Viole, OVVO Financial Systems
@@ -133,18 +132,18 @@ D.LPM<- function(degree.x,degree.y,x,y,target.x=mean(x),target.y=mean(y)){
   y[y>0]<- y[y>0]^degree.y
   return(sum(x*y)/length(x))
   }
-
+D.LPM<- Vectorize(D.LPM,vectorize.args = c('target.x','target.y'))
 
 #' Divergent-Upper Partial Moment
 #' (Upper Left Quadrant 2)
 #'
-#' This function generates a multivariate divergent upper partial moment for any degree or target.
-#' @param degree.x Degree for variable X.  \code{degree.x = 0} is frequency, \code{degree.x = 1} is area.
-#' @param degree.y Degree for variable Y.  \code{degree.y = 0} is frequency, \code{degree.y = 1} is area.
-#' @param x Variable X
-#' @param y Variable Y
-#' @param target.x Typically the mean of Variable X, but does not have to be.
-#' @param target.y Typically the mean of Variable Y, but does not have to be.
+#' This function generates a divergent upper partial moment between two variables for any degree or target.
+#' @param degree.x integer; Degree for variable X.  \code{(degree.x = 0)} is frequency, \code{(degree.x = 1)} is area.
+#' @param degree.y integer; Degree for variable Y.  \code{(degree.y = 0)} is frequency, \code{(degree.y = 1)} is area.
+#' @param x a numeric vector.
+#' @param y a numeric vector.
+#' @param target.x numeric; Typically the mean of Variable X for classical statistics equivalences, but does not have to be. (Vectorized)
+#' @param target.y numeric; Typically the mean of Variable Y for classical statistics equivalences, but does not have to be. (Vectorized)
 #' @return Divergent UPM of two variables
 #' @keywords partial moments, covariance
 #' @author Fred Viole, OVVO Financial Systems
@@ -163,4 +162,4 @@ D.UPM<- function(degree.x,degree.y,x,y,target.x=mean(x),target.y=mean(y)){
   y[y>0]<- y[y>0]^degree.y
   return(sum(x*y)/length(x))
  }
-
+D.UPM<- Vectorize(D.UPM,vectorize.args = c('target.x','target.y'))
