@@ -2,13 +2,14 @@
 #'
 #' Returns the uni-directional causality from observational data between two variables.  Causation nets out the univariate effect.
 #'
-#' @param x Variable
-#' @param y Variable
-#' @param tau Number of lagged observations to consider
+#' @param x a numeric vector.
+#' @param y a numeric vector.
+#' @param tau integer; Number of lagged observations to consider
+#' @param plot logical; \code{TRUE} (default) Plots the raw variables, tau normalized, and cross-normalized variables.
 #' @keywords causation
 #' @author Fred Viole, OVVO Financial Systems
 
-Uni.caus <- function(x,y,tau){
+Uni.caus <- function(x,y,tau,plot=TRUE){
 
 
   min.length = min(length(x),length(y))
@@ -16,37 +17,22 @@ Uni.caus <- function(x,y,tau){
   x.vectors = list()
   y.vectors = list()
 
-  ## Normalize x to x.tau
-  for (i in 0:tau){
-
-    x.vectors[[paste('x.tau.',i,sep="")]] <- numeric(0L)
-  }
-
-
-  for (i in 0:tau){
-    start = tau-i+1
-    end = min.length-i
-    x.vectors[[i+1]] = x[start:end]
-  }
-
-  x.vectors.tau = cbind.data.frame(x.vectors)
+## Create tau vectors
+    for (i in 0:tau){
+        x.vectors[[paste('x.tau.',i,sep="")]] <- numeric(0L)
+        y.vectors[[paste('y.tau.',i,sep="")]] <- numeric(0L)
+        start = tau-i+1
+        end = min.length-i
+        x.vectors[[i+1]] = x[start:end]
+        y.vectors[[i+1]] = y[start:end]
+    }
 
+  x.vectors.tau = do.call(cbind,x.vectors)
+  y.vectors.tau = do.call(cbind,y.vectors)
+## Normalize x to x.tau
   x.norm.tau <- NNS.norm(x.vectors.tau)[,1]
 
-  ## Normalize y to y.tau
-  for (i in 0:tau){
-
-    y.vectors[[paste('x.tau.',i,sep="")]] <- numeric(0L)
-
-  }
-  for (i in 0:tau){
-    start = tau-i+1
-    end = min.length-i
-    y.vectors[[i+1]] = y[start:end]
-  }
-
-  y.vectors.tau = cbind.data.frame(y.vectors)
-
+## Normalize y to y.tau
   y.norm.tau <- NNS.norm(y.vectors.tau)[,1]
 
 
@@ -60,13 +46,14 @@ Uni.caus <- function(x,y,tau){
   P.x.given.y = UPM(0,min(x.norm.to.y),y.norm.to.x) - UPM(0,max(x.norm.to.y),y.norm.to.x)
 
 
+
   ## Correlation of Normalized Variables
   rho.x.y = NNS.dep(x.norm.to.y,y.norm.to.x)$Dependence
 
   Causation.x.given.y= P.x.given.y*rho.x.y
 
 
-
+  if(plot==TRUE){
   par(mfrow=c(3,1))
 
   ## Raw Variable Plot
@@ -98,6 +85,9 @@ Uni.caus <- function(x,y,tau){
   legend('top',c("X","Y"), lty = 1,lwd=c(3,3),
          col=c('steelblue','red'),ncol=2,bty ="n")
 
+  par(mfrow=c(1,1))
+  }
+
   return(Causation.x.given.y)
 
 }
